@@ -2,17 +2,17 @@
 ## methods with generic defined in base
 ## ---------------------
 
-setMethod("as.matrix", "dcmle", function(x, ...) 
+setMethod("as.matrix", "dcmle", function(x, ...)
     as.matrix(as(x, "MCMClist"), ...))
-setMethod("as.matrix", "codaMCMC", function(x, ...) 
+setMethod("as.matrix", "codaMCMC", function(x, ...)
     as.matrix(as(x, "MCMClist"), ...))
 
-setMethod("as.array", "dcmle", function(x, ...) 
-    array(x@details@values, 
+setMethod("as.array", "dcmle", function(x, ...)
+    array(x@details@values,
         dim=c(x@details@niter, x@details@nvar, x@details@nchains),
         dimnames=list(NULL, x@details@varnames, NULL)))
-setMethod("as.array", "codaMCMC", function(x, ...) 
-    array(x@values, 
+setMethod("as.array", "codaMCMC", function(x, ...)
+    array(x@values,
         dim=c(x@niter, x@nvar, x@nchains),
         dimnames=list(NULL, x@varnames, NULL)))
 
@@ -50,7 +50,7 @@ setMethod("nclones", "codaMCMC", function(x, ...) NULL)
 ## coda type accessor functions and generics
 setGeneric("nvar", function(x) standardGeneric("nvar"))
 setGeneric("varnames", function(x, ...) standardGeneric("varnames"))
-setGeneric("chanames", function(x, ...) 
+setGeneric("chanames", function(x, ...)
     standardGeneric("chanames"))
 setGeneric("nchain", function(x) standardGeneric("nchain"))
 setGeneric("niter", function(x) standardGeneric("niter"))
@@ -60,35 +60,35 @@ setGeneric("mcpar", function(x) standardGeneric("mcpar"))
 
 setMethod("nvar", "dcmle", function(x) x@details@nvar)
 setMethod("varnames", "dcmle", function(x, ...) x@details@varnames)
-setMethod("chanames", "dcmle", function(x, ...) 
+setMethod("chanames", "dcmle", function(x, ...)
     chanames(as(x, "MCMClist"), ...))
 setMethod("nchain", "dcmle", function(x) x@details@nchains)
 setMethod("niter", "dcmle", function(x) x@details@niter)
 setMethod("thin", "dcmle", function(x) x@details@thin)
-setMethod("crosscorr", "dcmle", function(x) 
+setMethod("crosscorr", "dcmle", function(x)
     crosscorr(as(x, "MCMClist")))
 setMethod("mcpar", "dcmle", function(x) c(start(x), end(x), thin(x)))
 
 setMethod("nvar", "codaMCMC", function(x) x@nvar)
 setMethod("varnames", "codaMCMC", function(x, ...) x@varnames)
-setMethod("chanames", "codaMCMC", function(x, ...) 
+setMethod("chanames", "codaMCMC", function(x, ...)
     chanames(as(x, "MCMClist"), ...))
 setMethod("nchain", "codaMCMC", function(x) x@nchains)
 setMethod("niter", "codaMCMC", function(x) x@niter)
 setMethod("thin", "codaMCMC", function(x) x@thin)
-setMethod("crosscorr", "codaMCMC", function(x) 
+setMethod("crosscorr", "codaMCMC", function(x)
     crosscorr(as(x, "MCMClist")))
 setMethod("mcpar", "codaMCMC", function(x) c(start(x), end(x), thin(x)))
 
 ## these are necessary due to virtual class mcmc.list
 setMethod("nvar", "MCMClist", function(x) coda::nvar(x))
 setMethod("varnames", "MCMClist", function(x, ...) coda::varnames(x, ...))
-setMethod("chanames", "MCMClist", function(x, ...) 
+setMethod("chanames", "MCMClist", function(x, ...)
     coda::chanames(as(x, "MCMClist"), ...))
 setMethod("nchain", "MCMClist", function(x) coda::nchain(x))
 setMethod("niter", "MCMClist", function(x) coda::niter(x))
 setMethod("thin", "MCMClist", function(x) coda::thin(x))
-setMethod("crosscorr", "MCMClist", function(x) 
+setMethod("crosscorr", "MCMClist", function(x)
     coda::crosscorr(x))
 setMethod("mcpar", "MCMClist", function(x) c(start(x), end(x), thin(x)))
 
@@ -97,11 +97,11 @@ setMethod("mcpar", "MCMClist", function(x) c(start(x), end(x), thin(x)))
 ## ---------------------
 
 setMethod("coef", "dcmle", function(object, ...) object@coef)
-setMethod("coef", "codaMCMC", function(object, ...) 
+setMethod("coef", "codaMCMC", function(object, ...)
     coef(as(object, "MCMClist"), ...))
 
 setMethod("vcov", "dcmle", function(object, ...) object@vcov)
-setMethod("vcov", "codaMCMC", function(object, ...) 
+setMethod("vcov", "codaMCMC", function(object, ...)
     vcov(as(object, "MCMClist"), ...))
 
 setMethod("confint", "dcmle", function(object, parm, level = 0.95, ...) {
@@ -151,41 +151,39 @@ setMethod("frequency", "MCMClist", function(x, ...) 1/thin(x))
 
 setMethod("time", "dcmle", function(x, ...) {
     val <- seq(start(x), end(x), by = thin(x))
-    time(ts(data = val, 
+    time(ts(data = val,
         start = start(x), end = end(x), frequency = thin(x)), ...)
 })
 setMethod("time", "codaMCMC", function(x, ...) {
     val <- seq(start(x), end(x), by = thin(x))
-    time(ts(data = val, 
+    time(ts(data = val,
         start = start(x), end = end(x), frequency = thin(x)), ...)
 })
 
 setMethod("window", "dcmle", function(x, ...) {
-    as(window(as(x, "mcmc.list"), ...), "dcmle")
+    as(window(as(x, "MCMClist"), ...), "dcmle")
 })
 setMethod("window", "codaMCMC", function(x, ...) {
-    as(window(as(x, "mcmc.list"), ...), "codaMCMC")
+    as(window(as(x, "MCMClist"), ...), "codaMCMC")
 })
 
 ## no update for codaMCMC/dcCodaMCMC
-setMethod("update", "dcmle", function (object, ...) {
-    .local <- function (object, ..., evaluate = TRUE) 
-    {
-        call <- object@call
-        extras <- match.call(expand.dots = FALSE)$...
-        if (length(extras)) {
-            existing <- !is.na(match(names(extras), names(call)))
-            for (a in names(extras)[existing]) call[[a]] <- extras[[a]]
-            if (any(!existing)) {
-                call <- c(as.list(call), extras[!existing])
-                call <- as.call(call)
-            }
+setMethod("update", "dcmle", function (object, ..., evaluate = TRUE) {
+    call <- object@call
+    extras <- match.call(expand.dots = FALSE)$...
+    if (length(extras)) {
+        existing <- !is.na(match(names(extras), names(call)))
+        for (a in names(extras)[existing]) call[[a]] <- extras[[a]]
+        if (any(!existing)) {
+            call <- c(as.list(call), extras[!existing])
+            call <- as.call(call)
         }
-        if (evaluate) 
-            eval(call, parent.frame())
-        else call
     }
-    .local(object, ...)
+    if (evaluate) {
+        out <- eval(call, parent.frame())
+        out@call <- call
+        out
+    } else call
 })
 
 ## ---------------------
@@ -211,18 +209,20 @@ setMethod("stack", "codaMCMC", function(x, ...) {
 
 ## this displays a compact structure (without detailed dctable)
 #setGeneric("str", function(object, ...) standardGeneric("str"))
-setMethod("str", "dcmle", function(object, max.level=5L, ...) 
-    str(as(object, "MCMClist"), max.level=max.level, ...))
-setMethod("str", "dcCodaMCMC", function(object, max.level=3L, ...) 
+#setMethod("str", "dcmle", function(object, max.level=5L, ...)
+#    str(as(object, "MCMClist"), max.level=max.level, ...))
+setMethod("str", "dcmle", function(object, max.level=5L, ...)
+    utils::str(object, max.level=max.level, ...))
+setMethod("str", "dcCodaMCMC", function(object, max.level=3L, ...)
     str(as(object, "MCMClist"), max.level=max.level, ...))
 
-setMethod("head", "dcmle", function(x, ...) 
+setMethod("head", "dcmle", function(x, ...)
     head(as(x, "MCMClist"), ...))
-setMethod("tail", "dcmle", function(x, ...) 
+setMethod("tail", "dcmle", function(x, ...)
     tail(as(x, "MCMClist"), ...))
-setMethod("head", "codaMCMC", function(x, ...) 
+setMethod("head", "codaMCMC", function(x, ...)
     head(as(x, "MCMClist"), ...))
-setMethod("tail", "codaMCMC", function(x, ...) 
+setMethod("tail", "codaMCMC", function(x, ...)
     tail(as(x, "MCMClist"), ...))
 
 
@@ -240,19 +240,19 @@ setMethod("show", "dcmle", function(object) {
     print(coef(object))
 })
 
-setClass("summary.codaMCMC", 
+setClass("summary.codaMCMC",
     representation(
         settings = "integer",
         coef = "matrix"))
 
-setClass("summary.dcCodaMCMC", 
+setClass("summary.dcCodaMCMC",
     contains="summary.codaMCMC",
     representation(
         settings = "integer",
         coef = "matrix",
         convergence = "dcDiag"))
 
-setClass("summary.dcmle", 
+setClass("summary.dcmle",
     contains="summary.dcCodaMCMC",
     representation(
         title="character",
@@ -264,18 +264,18 @@ setMethod("summary", "codaMCMC", function(object, ...) {
         k <- 1L
     attributes(k) <- NULL
     settings <- c(
-        start=start(object), 
-        end=end(object), 
+        start=start(object),
+        end=end(object),
         thin=thin(object),
         n.iter=end(object)-start(object)+1,
-        n.chains=nchain(object), 
+        n.chains=nchain(object),
         n.clones=k)
     storage.mode(settings) <- "integer"
     coefs <- coef(object)
     se <- dcsd(object)
     cmat <- cbind(coefs, se)
     colnames(cmat) <- c("Estimate", "Std. Deviation")
-    new("summary.codaMCMC", 
+    new("summary.codaMCMC",
         settings=settings,
         coef = cmat)
 })
@@ -286,11 +286,11 @@ setMethod("summary", "dcCodaMCMC", function(object, ...) {
         k <- 1L
     attributes(k) <- NULL
     settings <- c(
-        start=start(object), 
-        end=end(object), 
+        start=start(object),
+        end=end(object),
         thin=thin(object),
         n.iter=end(object)-start(object)+1,
-        n.chains=nchain(object), 
+        n.chains=nchain(object),
         n.clones=k)
     storage.mode(settings) <- "integer"
     coefs <- coef(object)
@@ -299,7 +299,7 @@ setMethod("summary", "dcCodaMCMC", function(object, ...) {
     pval <- 2 * pnorm(-abs(zstat))
     cmat <- cbind(coefs, se, zstat, pval)
     colnames(cmat) <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
-    new("summary.dcCodaMCMC", 
+    new("summary.dcCodaMCMC",
         settings=settings,
         coef = cmat,
         convergence=dcdiag(object))
@@ -320,11 +320,11 @@ setMethod("summary", "dcmle", function(object, title, ...) {
         title <- paste(title, "\n\n", sep="")
     }
     settings <- c(
-        start=start(object), 
-        end=end(object), 
+        start=start(object),
+        end=end(object),
         thin=thin(object),
         n.iter=end(object)-start(object)+1,
-        n.chains=nchain(object), 
+        n.chains=nchain(object),
         n.clones=k)
     storage.mode(settings) <- "integer"
     coefs <- coef(object)
@@ -333,9 +333,9 @@ setMethod("summary", "dcmle", function(object, title, ...) {
     pval <- 2 * pnorm(-abs(zstat))
     cmat <- cbind(coefs, se, zstat, pval)
     colnames(cmat) <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
-    new("summary.dcmle", 
+    new("summary.dcmle",
         title=title,
-        call = object@call, 
+        call = object@call,
         settings=settings,
         coef = cmat,
         convergence=dcdiag(object))
@@ -345,10 +345,10 @@ setMethod("show", "summary.codaMCMC", function(object) {
     digits <- max(3, getOption("digits") - 3)
     cat("'codaMCMC' object\n")
     cat("\nSettings:\n")
-    print(data.frame(t(object@settings)), 
+    print(data.frame(t(object@settings)),
         digits=digits, row.names=FALSE)
     cat("\nCoefficients:\n")
-    printCoefmat(object@coef, 
+    printCoefmat(object@coef,
         digits = digits, signif.legend = TRUE)
     invisible(object)
 })
@@ -357,13 +357,13 @@ setMethod("show", "summary.dcCodaMCMC", function(object) {
     digits <- max(3, getOption("digits") - 3)
     cat("'dcCodaMCMC' object\n")
     cat("\nSettings:\n")
-    print(data.frame(t(object@settings)), 
+    print(data.frame(t(object@settings)),
         digits=digits, row.names=FALSE)
     cat("\nCoefficients:\n")
-    printCoefmat(object@coef, 
+    printCoefmat(object@coef,
         digits = digits, signif.legend = TRUE)
     cat("\nConvergence:\n")
-    print(object@convergence, 
+    print(object@convergence,
         digits=digits, row.names=FALSE)
     invisible(object)
 })
@@ -374,13 +374,13 @@ setMethod("show", "summary.dcmle", function(object) {
     cat("Call:\n")
     print(object@call)
     cat("\nSettings:\n")
-    print(data.frame(t(object@settings)), 
+    print(data.frame(t(object@settings)),
         digits=digits, row.names=FALSE)
     cat("\nCoefficients:\n")
-    printCoefmat(object@coef, 
+    printCoefmat(object@coef,
         digits = digits, signif.legend = TRUE)
     cat("\nConvergence:\n")
-    print(object@convergence, 
+    print(object@convergence,
         digits=digits, row.names=FALSE)
     invisible(object)
 })
@@ -389,16 +389,16 @@ setMethod("show", "summary.dcmle", function(object) {
 ## subsetting methods (generic from base -- no import needed)
 ## ---------------------
 
-setMethod("[[", signature(x = "codaMCMC"), function (x, i, j, ...) 
+setMethod("[[", signature(x = "codaMCMC"), function (x, i, j, ...)
         as(as.mcmc.list(x)[i], "codaMCMC"))
-setMethod("[[", signature(x = "dcCodaMCMC"), function (x, i, j, ...) 
+setMethod("[[", signature(x = "dcCodaMCMC"), function (x, i, j, ...)
         as(as.mcmc.list(x)[i], "dcCodaMCMC"))
-setMethod("[[", signature(x = "dcmle"), function (x, i, j, ...) 
+setMethod("[[", signature(x = "dcmle"), function (x, i, j, ...)
         as(as.mcmc.list(x)[i], "dcmle"))
 
 setMethod("[",
     signature(x = "codaMCMC"),
-    function (x, i, j, ..., drop = TRUE) 
+    function (x, i, j, ..., drop = TRUE)
     {
         if (missing(j))
             return(x[[i]])
@@ -408,7 +408,7 @@ setMethod("[",
     })
 setMethod("[",
     signature(x = "dcCodaMCMC"),
-    function (x, i, j, ..., drop = TRUE) 
+    function (x, i, j, ..., drop = TRUE)
     {
         if (missing(j))
             return(x[[i]])
@@ -418,7 +418,7 @@ setMethod("[",
     })
 setMethod("[",
     signature(x = "dcmle"),
-    function (x, i, j, ..., drop = TRUE) 
+    function (x, i, j, ..., drop = TRUE)
     {
         if (missing(j))
             return(x[[i]])
@@ -432,66 +432,65 @@ setMethod("[",
 ## diagnostic functions from coda and dclone
 ## ---------------------
 
-setGeneric("gelman.diag", function(x, ...) 
+setGeneric("gelman.diag", function(x, ...)
     standardGeneric("gelman.diag"))
-setMethod("gelman.diag", "MCMClist", function(x, ...) 
+setMethod("gelman.diag", "MCMClist", function(x, ...)
     coda::gelman.diag(x, ...))
-setMethod("gelman.diag", "codaMCMC", function(x, ...) 
+setMethod("gelman.diag", "codaMCMC", function(x, ...)
     gelman.diag(as(x, "MCMClist"), ...))
-setMethod("gelman.diag", "dcmle", function(x, ...) 
+setMethod("gelman.diag", "dcmle", function(x, ...)
     gelman.diag(as(x, "MCMClist"), ...))
 
-setGeneric("geweke.diag", function(x, ...) 
+setGeneric("geweke.diag", function(x, ...)
     standardGeneric("geweke.diag"))
-setMethod("geweke.diag", "MCMClist", function(x, ...) 
+setMethod("geweke.diag", "MCMClist", function(x, ...)
     coda::geweke.diag(x, ...))
-setMethod("geweke.diag", "codaMCMC", function(x, ...) 
+setMethod("geweke.diag", "codaMCMC", function(x, ...)
     geweke.diag(as(x, "MCMClist"), ...))
-setMethod("geweke.diag", "dcmle", function(x, ...) 
+setMethod("geweke.diag", "dcmle", function(x, ...)
     geweke.diag(as(x, "MCMClist"), ...))
 
-setGeneric("raftery.diag", function(x, ...) 
+setGeneric("raftery.diag", function(x, ...)
     standardGeneric("raftery.diag"))
-setMethod("raftery.diag", "MCMClist", function(x, ...) 
+setMethod("raftery.diag", "MCMClist", function(x, ...)
     coda::raftery.diag(x, ...))
-setMethod("raftery.diag", "codaMCMC", function(x, ...) 
+setMethod("raftery.diag", "codaMCMC", function(x, ...)
     raftery.diag(as(x, "MCMClist"), ...))
-setMethod("raftery.diag", "dcmle", function(x, ...) 
+setMethod("raftery.diag", "dcmle", function(x, ...)
     raftery.diag(as(x, "MCMClist"), ...))
 
-setGeneric("heidel.diag", function(x, ...) 
+setGeneric("heidel.diag", function(x, ...)
     standardGeneric("heidel.diag"))
-setMethod("heidel.diag", "MCMClist", function(x, ...) 
+setMethod("heidel.diag", "MCMClist", function(x, ...)
     coda::heidel.diag(x, ...))
-setMethod("heidel.diag", "codaMCMC", function(x, ...) 
+setMethod("heidel.diag", "codaMCMC", function(x, ...)
     heidel.diag(as(x, "MCMClist"), ...))
-setMethod("heidel.diag", "dcmle", function(x, ...) 
+setMethod("heidel.diag", "dcmle", function(x, ...)
     heidel.diag(as(x, "MCMClist"), ...))
 
-#setGeneric("autocorr.diag", function(mcmc.obj, ...) 
+#setGeneric("autocorr.diag", function(mcmc.obj, ...)
 #    standardGeneric("autocorr.diag"))
-setMethod("autocorr.diag", "MCMClist", function(mcmc.obj, ...) 
-    autocorr.diag(as(mcmc.obj, "mcmc.list"), ...))
-setMethod("autocorr.diag", "codaMCMC", function(mcmc.obj, ...) 
+setMethod("autocorr.diag", "MCMClist", function(mcmc.obj, ...)
+    coda::autocorr.diag(as(mcmc.obj, "mcmc.list"), ...))
+setMethod("autocorr.diag", "codaMCMC", function(mcmc.obj, ...)
     autocorr.diag(as(mcmc.obj, "MCMClist"), ...))
-setMethod("autocorr.diag", "dcmle", function(mcmc.obj, ...) 
+setMethod("autocorr.diag", "dcmle", function(mcmc.obj, ...)
     autocorr.diag(as(mcmc.obj, "MCMClist"), ...))
 
-#setGeneric("chisq.diag", function(x, ...) 
+#setGeneric("chisq.diag", function(x, ...)
 #    standardGeneric("chisq.diag"))
-setMethod("chisq.diag", "MCMClist", function(x, ...) 
+setMethod("chisq.diag", "MCMClist", function(x, ...)
     dclone::chisq.diag(x))
-setMethod("chisq.diag", "codaMCMC", function(x, ...) 
+setMethod("chisq.diag", "codaMCMC", function(x, ...)
     chisq.diag(as(x, "MCMClist"), ...))
-setMethod("chisq.diag", "dcmle", function(x, ...) 
+setMethod("chisq.diag", "dcmle", function(x, ...)
     chisq.diag(as(x, "MCMClist"), ...))
 
-#setGeneric("lambdamax.diag", function(x, ...) 
+#setGeneric("lambdamax.diag", function(x, ...)
 #    standardGeneric("lambdamax.diag"))
-setMethod("lambdamax.diag", "MCMClist", function(x, ...) 
+setMethod("lambdamax.diag", "MCMClist", function(x, ...)
     dclone::lambdamax.diag(x))
-setMethod("lambdamax.diag", "codaMCMC", function(x, ...) 
+setMethod("lambdamax.diag", "codaMCMC", function(x, ...)
     lambdamax.diag(as(x, "MCMClist"), ...))
-setMethod("lambdamax.diag", "dcmle", function(x, ...) 
+setMethod("lambdamax.diag", "dcmle", function(x, ...)
     lambdamax.diag(as(x, "MCMClist"), ...))
-
